@@ -1,5 +1,5 @@
 setMethod("asJSON", "array", function(x, collapse = TRUE, na = NULL, oldna = NULL,
-  matrix = c("rowmajor", "columnmajor"), ...) {
+  matrix = c("rowmajor", "columnmajor"), auto_unbox = FALSE, ...) {
 
   #validate
   matrix <- match.arg(matrix);
@@ -9,9 +9,9 @@ setMethod("asJSON", "array", function(x, collapse = TRUE, na = NULL, oldna = NUL
     na <- oldna;
   }
 
-  # row based json
   # if collapse == FALSE, then this matrix is nested inside a data frame,
   # and therefore row major is required to match dimensions
+  # dont pass auto_unbox (never unbox within matrix)
   margin <- ifelse(identical(matrix, "columnmajor") && isTRUE(collapse), length(dim(x)), 1);
   tmp <- apply(x, margin, asJSON, matrix = matrix, na = na, ...)
 
