@@ -13,16 +13,12 @@ simplify <- function(x, simplifyVector = TRUE, simplifyDataFrame = TRUE, simplif
     if(isTRUE(simplifyDate) && is.data.frame(mydf) && is.datelist(mydf)){
       return(structure(mydf[["$date"]]/1000, class=c("POSIXct", "POSIXt")))
     }
-    if ("$row" %in% names(mydf)) {
-      row.names(mydf) <- mydf[["$row"]]
-      mydf["$row"] <- NULL
-    }
     return(mydf)
   }
 
   # or a scalar list (atomic vector)
   if (isTRUE(simplifyVector) && is.null(names(x)) && is.scalarlist(x)) {
-    return(null2na(x))
+    return(list_to_vec(x))
   }
 
   # apply recursively
@@ -32,11 +28,11 @@ simplify <- function(x, simplifyVector = TRUE, simplifyDataFrame = TRUE, simplif
   # fix for mongo style dates turning into scalars *after* simplifying
   # only happens when simplifyDataframe=FALSE
   if(isTRUE(simplifyVector) && is.scalarlist(out) && all(vapply(out, is, logical(1), "POSIXt"))){
-    return(structure(null2na(out), class=c("POSIXct", "POSIXt")))
+    return(structure(list_to_vec(out), class=c("POSIXct", "POSIXt")))
   }
 
-  # test for matrix. Note that we have to take another look at x (before null2na on
-  # its elements) to differentiate between matrix and vector
+  # test for matrix. Note that we have to take another look at x (before
+  # list_to_vec on its elements) to differentiate between matrix and vector.
   if (isTRUE(simplifyMatrix) && isTRUE(simplifyVector) && is.matrixlist(out) && all(unlist(vapply(x, is.scalarlist, logical(1))))) {
     if(isTRUE(columnmajor)){
       return(do.call(cbind, out))
@@ -96,36 +92,6 @@ simplify <- function(x, simplifyVector = TRUE, simplifyDataFrame = TRUE, simplif
   return(out)
 }
 
-is.scalarlist <- function(x) {
-  if(!is.list(x)) return(FALSE)
-  for(i in x){
-    if(!is.atomic(i) || length(i) > 1) return(FALSE)
-  }
-  return(TRUE)
-}
-
-is.namedlist <- function(x) {
-  isTRUE(is.list(x) && !is.null(names(x)))
-}
-
-is.unnamedlist <- function(x) {
-  isTRUE(is.list(x) && is.null(names(x)))
-}
-
-is.recordlist <- function(x) {
-  # recordlist is an array with only objects or NULL NULL appears when this is a
-  # nested data frame, but some records do not contain this data frame at all.
-  if (!(is.unnamedlist(x) && length(x))) {
-    return(FALSE)
-  }
-  at_least_one_object = FALSE
-  for(i in x){
-    if(!(is.namedlist(i) || is.null(i))) return(FALSE)
-    if(!at_least_one_object && is.namedlist(i)) at_least_one_object <- TRUE
-  }
-  return(at_least_one_object)
-}
-
 is.matrixlist <- function(x) {
   isTRUE(is.list(x)
     && length(x)
